#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("_ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  ")]
//    [Gui.Design.DisplayName("_ECO2New_PaintBars_Sharkypkg_2")]
	/* 
	V1.1 - Fixed Plot Overflow problem.  Code was not skipping enough warm-up bars and was getting an overflow on some charts
											- now skips 10 bars
	Adapted from Blau's Momentum/Direction/Divergence by zoltran (Wes S.) 
	
					// Formula for Candlestick oscilator from Blaus book is 
				//                      EMA(EMA(close-open),r),s)
				//    CSI(r,s)= 100 x  --------------------------
				//                        EMA(EMA(high-low),r),s)
				//
				// The 'Ergodic' version adds signal line, wich is a 5 bar ema of the CSI
				//


	Trading Ergodics with the Trend - Rules

   1. Enter or hold position only when slope of _ECO2New_PaintBars_Sharkypkg_2 Signal line has the same direction as the trend
   2. Stand aside when slope of _ECO2New_PaintBars_Sharkypkg_2 Signal Line is in the opposite direction of trend
   3. Enter or exit position when _ECO2New_PaintBars_Sharkypkg_2 and its Signal Line cross
   4. Take note when the _ECO2New_PaintBars_Sharkypkg_2 is 'inside' it's signal line.  This indicates failing momemntum
	   This is what the magenta dot signifies
	v1.2 - 7/18/09 - zeller4 - Added Paint bars for Sharky
	
	
	*/ 
    public class _ECO2New_PaintBars_Sharkypkg_2 : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int fast = 7; // Default setting for Fast 3
            private int slow = 21; // Default setting for Slow 13
            private int signalLen = 4; // Default setting for SignalLen 5
        // User defined variables (add any user defined variables below)
		DataSeries				fastEma;
		DataSeries				fastAbsEma;
		DataSeries				slowEma;
		DataSeries				slowAbsEma;
		DataSeries				closeopen;
		DataSeries				highlow;
		DataSeries				eco;
		DataSeries				average;
		bool					histogramType = true;
		private bool		showText = false;//true;
		private bool		textOnLeft = false;
		private TextPosition bPosition = TextPosition.BottomLeft;
		private TextPosition tPosition = TextPosition.TopLeft;
//		double average;
//		double eco;
		private bool		showEntries = false;//true;
		private bool		alerts = false;
		private int	edownbar	=	0;
		private int	edownplot	=	0;
		private int	triangleDn	=	0;
		private int	eupbar	=	0;
		private int	eupplot	=	0;
		private int	triangleUp	=	0;
		
		private bool colorbars = true;
		private Color barColorUp = Color.Blue;
		private Color barColorDown = Color.Red;
		private Color barColorNeutral = Color.Yellow;
		private Color barColorOutline = Color.Black;//DimGray;
		// Coloring of Region
			private bool bandArea  = true;
			private Color bandAreaColor = Color.Navy;
		
		
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {

			// The add statements are in this odd order so that 'z' order of the plots works right... 
						// Fading dot plots on top of the Signal 
			               // Signal plot on top of the Main indicator
			
			
			Add(new Plot(new Pen(Color.Transparent, 2), PlotStyle.Dot,	"Fading"));	   		// Values[0]//Magenta
            Add(new Plot(new Pen(Color.Transparent, 2), PlotStyle.Line, "Signal")); 			// Values[1]//White			
            Add(new Plot(new Pen(Color.Lime, 5),	PlotStyle.Line,	"Rising"));		// Values[2]
            Add(new Plot(new Pen(Color.Red,5), PlotStyle.Line,	"Falling"));		// Values[3]
			Add(new Plot(new Pen(Color.Gold, 5), PlotStyle.Hash, "Main"));		  		// Values[4]//same as neutral?			
            Add(new Plot(new Pen(Color.DarkGreen, 4), PlotStyle.Bar,	"RisingHistogram"));		// Values[5]			
            Add(new Plot(new Pen(Color.Crimson, 4), PlotStyle.Bar,	"FallingHistogram"));		// Values[6]
			Add(new Plot(new Pen(Color.Yellow,6000), PlotStyle.Hash, "Neutral"));//Values[7]
			Add(new Plot(new Pen(Color.Blue,1), PlotStyle.Line, "Eight"));//Values[8]
			Add(new Plot(new Pen(Color.Blue,1), PlotStyle.Line, "MinusEight"));//Values[9]
			
			Add(new Line(new Pen(Color.Lime, 4), 20, "OverBought"));
			Add(new Line(new Pen(Color.Navy, 1), 8, "Zero1"));
			Add(new Line(new Pen(Color.Navy, 1), -8, "Zero2"));
			Add(new Line(new Pen(Color.Red, 4), -20, "OverSold"));
			
            CalculateOnBarClose	= false;
            Overlay				= false;
            PriceTypeSupported	= false;
			DrawOnPricePanel 	= false;
			DisplayInDataBox 	= true;
 
			// Init user data series
			closeopen 			= new DataSeries(this);	 
			highlow  			= new DataSeries(this);	// Init the data series
			fastEma 			= new DataSeries(this); 
			fastAbsEma 			= new DataSeries(this);
			slowEma 			= new DataSeries(this);
			slowAbsEma 			= new DataSeries(this);
			eco					= new DataSeries(this);
			average				= new DataSeries(this);	
			this.BarsRequired   = 1; //Slow+SignalLen+2;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (CurrentBar <3 ) return;
			closeopen.Set(Close[0]-Open[0]);					// Store the result of close - open
			highlow.Set(High[0] - Low[0]);						// Store the result of high - low            
			Eight.Set(8);
			MinusEight.Set(-8);
			if(BandArea)
				{
					//DrawRegion("Bollinger Upper Region", CurrentBar, 0, DynamicSR_Color(55).Resistance, DynamicSR_Color(55).Support, Color.Black, Color.Blue, 1);
					//DrawRegion("tag1", CurrentBar, 0, Resistance, Support, Color.Empty, Color.LimeGreen,2);
					DrawRegion("tag1", CurrentBar, 0, Eight, MinusEight, Color.Empty, BandAreaColor,8);
				}
			if (CurrentBar < Slow+Fast+1)
			
			{
				for (int index = 0; index <= 6; index++) 
				{
					Values[index].Reset();
				}					
				fastEma.Reset(); 
				fastAbsEma.Reset();
				slowEma.Reset();
				slowAbsEma.Reset();
				eco.Reset();
				average.Reset();	
				
				return	;		// Skip number of bars used for the _ECO2New_PaintBars_Sharkypkg_2 and it's EMA. .. warm up time  Overkill, but safe
			}
			else
			{

				// Formula for Candlestick oscilator from Blaus book is 
				//                      EMA(EMA(close-open),r),s)
				//    CSI(r,s)= 100 x  --------------------------
				//                        EMA(EMA(high-low),r),s)
				//
				// The 'Ergodic' version adds signal line, wich is a 5 bar ema of the CSI
				//
				
				eco.Set(100 * EMA(EMA(closeopen,slow),fast)[0] / EMA(EMA(highlow,slow),fast)[0]) ;

				if (CurrentBar > Slow+Fast+SignalLen+2)
					average.Set(EMA(eco,SignalLen)[0]);	    // Take a 5 bar EMA of the _ECO2New_PaintBars_Sharkypkg_2 (stored in collection Values[4]				
				Values[1].Set(average[0]);					// Plot the Signal Line				
				Values[4].Set(eco[0]);						// Plot main _ECO2New_PaintBars_Sharkypkg_2 line 
				
// The following code does the multicolor paints using extra plots for each color				
				Values[2].Reset();// Rising / Reset other lines to 0
				Values[3].Reset();// Falling				
				Values[5].Reset();// Rising Histogram		
				Values[6].Reset();// Falling Histogram
				
				
			if (eco[0]>eco[1])    // Plot green bars for rising eco, red for falling		
				{
//					if (eco[1]<eco[2]) Values[2].Set(1,eco[1]);//   connect prior secgment Paint falling eco  if (CurrentBar > Slow+Fast+SignalLen)
					Values[2].Set(eco[0]); 						    //    Paint Rising _ECO2New_PaintBars_Sharkypkg_2 Line
					
 				}
				else if (eco[0]<eco[1])
				{
//					if (eco[1]> eco[2])Values[3].Set(1,eco[1]);	//   connect prior secgment Paint falling eco
					Values[3].Set(eco[0]);						//    Paint falling eco

				}
			if (HistogramType)	
			{	
			if (eco[0]>0 ) Values[5].Set(eco[0]);						//    Paint histogram above zero
				else	Values[6].Set(eco[0]);							//    Paint histogram below zero	
			}
			
			else
				
 			{
				if (Rising(eco)) Values[5].Set(eco[0]);					//    Paint histogram Rising
				else	Values[6].Set(eco[0]);							//    Paint histogram Falling
			}
				
				
				if (eco[0]<0 && average[0] < eco[0]) Values[0].Set(average[0]); // Plot the 'Fading' dots if signal is outside of the _ECO2New_PaintBars_Sharkypkg_2
				if (eco[0]>0 && average[0] > eco[0]) Values[0].Set(average[0]); // This indicates declining momentum
					else Values[1].Set(eco[0]);							//defautls to same as eco 
/////////////////////////////////////////////////////////
				/// COLOR BARS //////////////
/////////////////////////////////////////////////////////
			if ((eco[0] < eco[1] && eco[1] > eco[2]) ||
				(eco[0] > eco[1] && eco[1] < eco[2])
				)
			{
				if (ColorBars)
					{
						CandleOutlineColor = BarColorOutline;
						BarColor = BarColorNeutral; 
					}
			}
			else
			if (eco[0] > eco[1] 
				)
				{ 
					if (ColorBars)
					{ 
						CandleOutlineColor = BarColorOutline;
						BarColor = BarColorUp; 
					}
				}
			else 
			if (ECOFalling[0] < ECOFalling[1]
				)
				{ 
					if (ColorBars)
					{
						CandleOutlineColor = BarColorOutline;
						BarColor = BarColorDown; 
					}
				}

				
				
 
//--Text Box Info--//
				
			double ECOminus = Math.Abs(eco[1]-eco[0]);
			double ECOplus = Math.Abs(eco[0]-eco[1]);	
			
			if(textOnLeft)			
			{bPosition = TextPosition.BottomLeft;
			tPosition = TextPosition.TopLeft;}
			else
			{bPosition = TextPosition.BottomRight;
			tPosition = TextPosition.TopRight;}
						
			if(showText)
			{
//				if(eco[0]<eco[1])
//			DrawTextFixed("EcoDown", " ECO Diff -" + ECOminus.ToString("0.00"), bPosition, Color.Black, new Font("Arial Narrow", 12), Color.Crimson, Color.Red, 10);
//				else
//			RemoveDrawObject("EcoDown");
//				
//				if(eco[0]>eco[1])
//			DrawTextFixed("EcoUp", " ECO Diff +" + ECOplus.ToString("0.00"), bPosition, Color.Black, new Font("Arial Narrow", 12), Color.DarkGreen, Color.LimeGreen, 10);
//				else
//			RemoveDrawObject("EcoUp");
//			
//			if(eco[0]<0 && average[0]<0 && eco[0]<average[0])
//			DrawTextFixed("Short", " SHORT", tPosition, Color.Black, new Font("Arial Narrow", 12), Color.Crimson, Color.Orange, 10);
//				else
//			RemoveDrawObject("Short");
			
			if(eco[0]>0 && average[0]>0 && eco[0]>average[0])
			DrawTextFixed("Long", " LONG", tPosition, Color.Black, new Font("Arial Narrow", 12), Color.Crimson, Color.Orange, 10);
				else
			RemoveDrawObject("Long");
			
			if(eco[0]>0 && average[0]>0 && eco[0]<average[0] || eco[0]<0 && average[0]<0 && eco[0]>average[0])
			DrawTextFixed("Fading", " FADING", tPosition, Color.Black, new Font("Arial Narrow", 12), Color.Crimson, Color.Orange, 10);
				else
			RemoveDrawObject("Fading");
			}
			
		//Triangle Plotting//
					
					if(average[0] > 0 || average[0] < eco[0] || eco[0] > 0)
				triangleDn = 0;
					if(average[0] < 0 || average[0] > eco[0] || eco[0] < 0)
				triangleUp = 0;
					
			if(showEntries)					
		{	
		
		if(CrossBelow(average, 0, 1) && eco[0] < average[0] && triangleDn == 0 || CrossAbove(average, eco, 1) && average[0] < 0 && triangleDn == 0)	
		{DrawTriangleDown("EcoDT", true, 0, 0, Color.Transparent);
		if (alerts == true)					
		Alert("DnTrend",NinjaTrader.Cbi.Priority.Medium,"Dn Trend Pending","Drip.wav",6,Color.Black,Color.Yellow);	
		edownbar = CurrentBar;
		edownplot = 1;}
			
		if(edownplot == 1 && CurrentBar == edownbar + 1)
		{RemoveDrawObject("EcoDT");
		edownplot = 0;
		if(eco[1] < average[1] && average[1] < 0 && triangleDn == 0)
		{DrawTriangleDown(CurrentBar.ToString() + "EcoDTSolid", true, 1, 0, Color.Red);
			if(eco[1] > eco[2] || average[1] > average[2])
				DrawTriangleDown(CurrentBar.ToString() + "EcoDTSolidDark", true, 1, 0, Color.LightSalmon);
		triangleDn = 1;
		if (alerts == true)					
		Alert("DnTrendFinal",NinjaTrader.Cbi.Priority.Medium,"Dn Trend","Alert2.wav",6,Color.Black,Color.Yellow);}
		}
		
			
		
		
		if(CrossAbove(average, 0, 1) && eco[0] > average[0] && triangleUp == 0 || CrossBelow(average, eco, 1) && average[0] > 0 && triangleUp == 0)
		{DrawTriangleUp("EcoUT", true, 0, 0, Color.Transparent);
		if (alerts == true)					
		Alert("UpTrend",NinjaTrader.Cbi.Priority.Medium,"Up Trend Pending","Drip.wav",6,Color.Black,Color.Yellow);	
		eupbar = CurrentBar;
		eupplot = 1;}
		
		if(eupplot == 1 && CurrentBar == eupbar + 1)
		{RemoveDrawObject("EcoUT");
		eupplot = 0;
		if(eco[1] > average[1] && average[1] > 0 && triangleUp == 0)
		{DrawTriangleUp(CurrentBar.ToString() + "EcoUTSolid", true, 1, 0, Color.Green);
			if(eco[1] < eco[2] || average[1] < average[2])
				DrawTriangleUp(CurrentBar.ToString() + "EcoUTSolidDark", true, 1, 0, Color.GreenYellow);
		triangleUp = 1;
		if (alerts == true)					
		Alert("UpTrendFinal",NinjaTrader.Cbi.Priority.Medium,"Up Trend","Alert2.wav",6,Color.Black,Color.Yellow);}
		}
		}
			
			
			
			}
        }

        #region Properties
        
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Signal
        {
            get { return Values[1]; }
        }
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries ECORising
        {
            get { return Values[2]; }
        }
		
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries ECOFalling
        {
            get { return Values[3]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Main
        {
            get { return Values[4]; }
        }
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries ECONeutral
        {
            get { return Values[7]; }
        }
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Eight
        {
            get { return Values[8]; }
        }
        
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries MinusEight
        {
            get { return Values[9]; }
        }
       
        [Description("Fast EMA")]
        [Category("Parameters")]
        public int Fast
        {
            get { return fast; }
            set { fast = Math.Max(1, value); }
        }

        [Description("Slow EMA")]
        [Category("Parameters")]
        public int Slow
        {
            get { return slow; }
            set { slow = Math.Max(1, value); }
        }

        [Description("Signal EMA")]
        [Category("Parameters")]
        public int SignalLen
        {
            get { return signalLen; }
            set { signalLen = Math.Max(1, value); }
        }
        [Description("Histogram Paint Type. True = Green/Red Above/Below 0.  False = Histogram Color shows Rising/Falling ECO")]
        [Category("Display Parameters")]
        public bool HistogramType
        {
            get { return histogramType; }
            set { histogramType = value; }
        }		
		
		[Description("Show Text Info.")]
        [Category("Display Parameters")]
        public bool ShowText
        {
            get { return showText; }
            set { showText = value; }
        }
		
		[Description("Text on left of chart? For those with no right margin.")]
        [Category("Display Parameters")]
        public bool TextOnLeft
        {
            get { return textOnLeft; }
            set { textOnLeft = value; }
        }
		
		[Description("Show Entry Triangles")]
        [Category("Display Parameters")]
        public bool ShowEntries
        {
            get { return showEntries; }
            set { showEntries = value; }
        }
		
		[Description("Sound alert warning.")]
		[Gui.Design.DisplayName ("Turn sound alert on?")]
        [Category("Display Parameters")]
        public bool Alerts
        {
            get { return alerts; }
            set { alerts = value; }
        }
		[Description("Color price bars?")]
        [Category("Visual")]
        [Gui.Design.DisplayName("01. Color Bars?")]
        public bool ColorBars
        {
            get { return colorbars; }
            set { colorbars = value; }
        }

        /// <summary>
        /// </summary>
        [XmlIgnore()]
        [Description("Color of up bars")]
        [Category("Visual")]
        [Gui.Design.DisplayNameAttribute("02. Up color")]
        public Color BarColorUp
        {
            get { return barColorUp; }
            set { barColorUp = value; }
        }
		
        /// <summary>
        /// </summary>
        [Browsable(false)]
        public string barColorUpSerialize
        {
            get { return NinjaTrader.Gui.Design.SerializableColor.ToString(barColorUp); }
            set { barColorUp = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
        }

        /// <summary>
        /// </summary>
        [XmlIgnore()]
        [Description("Color of down bars")]
        [Category("Visual")]
        [Gui.Design.DisplayNameAttribute("03. Down color")]
        public Color BarColorDown
        {
            get { return barColorDown; }
            set { barColorDown = value; }
        }

        /// <summary>
        /// </summary>
        [Browsable(false)]
        public string barColorDownSerialize
        {
            get { return NinjaTrader.Gui.Design.SerializableColor.ToString(barColorDown); }
            set { barColorDown = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
        }
        
        /// <summary>
        /// </summary>
        [XmlIgnore()]
        [Description("Color of neutral bars")]
        [Category("Visual")]
        [Gui.Design.DisplayNameAttribute("04. Neutral color")]
        public Color BarColorNeutral
        {
            get { return barColorNeutral; }
            set { barColorNeutral = value; }
        }

        /// <summary>
        /// </summary>
        [Browsable(false)]
        public string barColorNeutralSerialize
        {
            get { return NinjaTrader.Gui.Design.SerializableColor.ToString(barColorNeutral); }
            set { barColorNeutral = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
        }
		/// <summary>
        /// </summary>
        [XmlIgnore()]
        [Description("Color of bar outline")]
        [Category("Visual")]
        [Gui.Design.DisplayNameAttribute("05. Outline color")]
        public Color BarColorOutline
        {
            get { return barColorOutline; }
            set { barColorOutline = value; }
        }

        /// <summary>
        /// </summary>
        [Browsable(false)]
        public string barColorOutlineSerialize
        {
            get { return NinjaTrader.Gui.Design.SerializableColor.ToString(barColorOutline); }
            set { barColorOutline = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
        }
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        [Description("Have ColorBand between support and resistance")]
		[Category("Region")]
		public bool BandArea
		{
			get { return bandArea; }
			set { bandArea = value; }
		}
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        [Description("Color of Band between support and resistance")]
		[Category("Region")]
//		[XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Color BandAreaColor
		{
			get { return bandAreaColor; }
			set { bandAreaColor = value; }
		}
		
		#endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private _ECO2New_PaintBars_Sharkypkg_2[] cache_ECO2New_PaintBars_Sharkypkg_2 = null;

        private static _ECO2New_PaintBars_Sharkypkg_2 check_ECO2New_PaintBars_Sharkypkg_2 = new _ECO2New_PaintBars_Sharkypkg_2();

        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        public _ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(int fast, int signalLen, int slow)
        {
            return _ECO2New_PaintBars_Sharkypkg_2(Input, fast, signalLen, slow);
        }

        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        public _ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(Data.IDataSeries input, int fast, int signalLen, int slow)
        {
            check_ECO2New_PaintBars_Sharkypkg_2.Fast = fast;
            fast = check_ECO2New_PaintBars_Sharkypkg_2.Fast;
            check_ECO2New_PaintBars_Sharkypkg_2.SignalLen = signalLen;
            signalLen = check_ECO2New_PaintBars_Sharkypkg_2.SignalLen;
            check_ECO2New_PaintBars_Sharkypkg_2.Slow = slow;
            slow = check_ECO2New_PaintBars_Sharkypkg_2.Slow;

            if (cache_ECO2New_PaintBars_Sharkypkg_2 != null)
                for (int idx = 0; idx < cache_ECO2New_PaintBars_Sharkypkg_2.Length; idx++)
                    if (cache_ECO2New_PaintBars_Sharkypkg_2[idx].Fast == fast && cache_ECO2New_PaintBars_Sharkypkg_2[idx].SignalLen == signalLen && cache_ECO2New_PaintBars_Sharkypkg_2[idx].Slow == slow && cache_ECO2New_PaintBars_Sharkypkg_2[idx].EqualsInput(input))
                        return cache_ECO2New_PaintBars_Sharkypkg_2[idx];

            _ECO2New_PaintBars_Sharkypkg_2 indicator = new _ECO2New_PaintBars_Sharkypkg_2();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Fast = fast;
            indicator.SignalLen = signalLen;
            indicator.Slow = slow;
            indicator.SetUp();

            _ECO2New_PaintBars_Sharkypkg_2[] tmp = new _ECO2New_PaintBars_Sharkypkg_2[cache_ECO2New_PaintBars_Sharkypkg_2 == null ? 1 : cache_ECO2New_PaintBars_Sharkypkg_2.Length + 1];
            if (cache_ECO2New_PaintBars_Sharkypkg_2 != null)
                cache_ECO2New_PaintBars_Sharkypkg_2.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cache_ECO2New_PaintBars_Sharkypkg_2 = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator._ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(int fast, int signalLen, int slow)
        {
            return _indicator._ECO2New_PaintBars_Sharkypkg_2(Input, fast, signalLen, slow);
        }

        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        public Indicator._ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(Data.IDataSeries input, int fast, int signalLen, int slow)
        {
            return _indicator._ECO2New_PaintBars_Sharkypkg_2(input, fast, signalLen, slow);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator._ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(int fast, int signalLen, int slow)
        {
            return _indicator._ECO2New_PaintBars_Sharkypkg_2(Input, fast, signalLen, slow);
        }

        /// <summary>
        /// _ECO2New_PaintBars_Sharkypkg_2(Ergodic Candlestick Oscilator.  The _ECO2New_PaintBars_Sharkypkg_2 is a Momentum Oscillator that is not affected by opening gaps.  See William Blau's Momentum/Direction/Divergence book  
        /// </summary>
        /// <returns></returns>
        public Indicator._ECO2New_PaintBars_Sharkypkg_2 _ECO2New_PaintBars_Sharkypkg_2(Data.IDataSeries input, int fast, int signalLen, int slow)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator._ECO2New_PaintBars_Sharkypkg_2(input, fast, signalLen, slow);
        }

    }
}
#endregion
